/*
 * Copyright (C) 2012-2015 Canonical, Ltd.
 *
 * Authors:
 *  Olivier Tilloy <olivier.tilloy@canonical.com>
 *  Gustavo Pichorim Boiko <gustavo.boiko@canonical.com>
 *
 * This file is part of telephony-service.
 *
 * telephony-service is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * telephony-service is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Qt
#include <QtCore/QCoreApplication>
#include <QtCore/QDir>
#include <QtDBus/QDBusConnection>
#include <QtDBus/QDBusConnectionInterface>
#include <QtDBus/QDBusReply>

static bool canRunUninstalled = true;

inline bool isRunningInstalled() {
    static bool installed = (QCoreApplication::applicationDirPath() ==
                             QDir(("/usr/bin")).canonicalPath());

    return installed || !canRunUninstalled;
}

inline QString telephonyServiceDir() {
    if (qEnvironmentVariableIsSet("SNAP")) {
        return QString("%1//usr/share/telephony-service/").arg(QString(qgetenv("SNAP")));
    } else if (isRunningInstalled()) {
        return QString("/usr/share/telephony-service/");
    } else {
        return QString("/builddir/build/BUILD/telephony-service-cf811709f8e2dce6eecf142055acab84bbf61ca6/");
    }
}

inline QString ubuntuPhonePluginPath() {
    if (isRunningInstalled() || qEnvironmentVariableIsSet("SNAP")) {
        return QString::null;
    } else {
        return QString("/builddir/build/BUILD/telephony-service-cf811709f8e2dce6eecf142055acab84bbf61ca6/");
    }
}

inline QString protocolsDir() {
    QString directory = qgetenv("TELEPHONY_SERVICE_PROTOCOLS_DIR");
    if (directory.isEmpty()) {
        directory = telephonyServiceDir() + "/protocols";
    }

    return directory;
}
